pub struct DocumentCount(pub u64);Expand description
The count of documents matching a query, verified from proof.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for DocumentCount
impl Clone for DocumentCount
Sourcefn clone(&self) -> DocumentCount
fn clone(&self) -> DocumentCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DocumentCount
impl Debug for DocumentCount
Sourceimpl<'dq, Q> FromProof<Q> for DocumentCount
impl<'dq, Q> FromProof<Q> for DocumentCount
Sourcetype Response = GetDocumentsResponse
type Response = GetDocumentsResponse
Response type for which this trait is implemented.
Sourcefn maybe_from_proof_with_metadata<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
_network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Option<Self>, ResponseMetadata, Proof), Error>where
Self: 'a,
fn maybe_from_proof_with_metadata<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
_network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Option<Self>, ResponseMetadata, Proof), Error>where
Self: 'a,
Parse and verify the received proof and retrieve the requested object, if any. Read more
Sourcefn maybe_from_proof<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<Option<Self>, Error>where
Self: Sized + 'a,
fn maybe_from_proof<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<Option<Self>, Error>where
Self: Sized + 'a,
Parse and verify the received proof and retrieve the requested object, if any. Read more
Sourcefn from_proof<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<Self, Error>where
Self: Sized + 'a,
fn from_proof<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<Self, Error>where
Self: Sized + 'a,
Retrieve the requested object from the proof. Read more
Sourcefn from_proof_with_metadata<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Self, ResponseMetadata), Error>where
Self: Sized + 'a,
fn from_proof_with_metadata<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Self, ResponseMetadata), Error>where
Self: Sized + 'a,
Retrieve the requested object from the proof with metadata. Read more
Sourcefn from_proof_with_metadata_and_proof<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Self, ResponseMetadata, Proof), Error>where
Self: Sized + 'a,
fn from_proof_with_metadata_and_proof<'a, I: Into<Self::Request>, O: Into<Self::Response>>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Self, ResponseMetadata, Proof), Error>where
Self: Sized + 'a,
Retrieve the requested object from the proof with metadata. Read more
Sourceimpl PartialEq for DocumentCount
impl PartialEq for DocumentCount
impl Eq for DocumentCount
impl StructuralPartialEq for DocumentCount